@@ -3,6 +3,6 @@ library(WebAnalytics)
 
 test_that("escape string works", {
   expect_equal(laTeXEscapeString("~!@#$%^&*(){}[]_-|\\"),
-               "\\textasciitilde{}!@\\#\\$\\%\textasciicircum{}\\&*()\\{\\}[]\\_-|textbackslash\\{\\}")
+               "\\textasciitilde{}!@\\#\\$\\%\textasciicircum{}\\&*()\\{\\}[]\\_-|\\textbackslash\\{\\}")
 })
 
